# marqeta-client
Simplified management of your payment programs

This Python package is automatically generated by the [OpenAPI Generator](https://openapi-generator.tech) project:

- API version: 3.0.0
- Package version: 3.0.0
- Build package: org.openapitools.codegen.languages.PythonNextgenClientCodegen

## Requirements.

Python 3.7+

## Installation & Usage
### pip install

If the python package is hosted on a repository, you can install directly using:

```sh
pip install git+https://github.com/SwadeshInc/marqeta-client.git
```
(you may need to run `pip` with root permission: `sudo pip install git+https://github.com/SwadeshInc/marqeta-client.git`)

Then import the package:
```python
import marqeta_client
```

### Setuptools

Install via [Setuptools](http://pypi.python.org/pypi/setuptools).

```sh
python setup.py install --user
```
(or `sudo python setup.py install` to install the package for all users)

Then import the package:
```python
import marqeta_client
```

### Tests

Execute `pytest` to run the tests.

## Getting Started

Please follow the [installation procedure](#installation--usage) and then run the following:

```python
from __future__ import print_function

import time
import marqeta_client
from marqeta_client.rest import ApiException
from pprint import pprint

# Defining the host is optional and defaults to /v3
# See configuration.py for a list of all supported configuration parameters.
configuration = marqeta_client.Configuration(
    host = "/v3"
)



# Enter a context with an instance of the API client
with marqeta_client.ApiClient(configuration) as api_client:
    # Create an instance of the API class
    api_instance = marqeta_client.AcceptedCountriesApi(api_client)
    count = 5 # int | Number of accepted countries to retrieve (optional) (default to 5)
    start_index = 0 # int | Start index (optional) (default to 0)
    name = 'name_example' # str | Name (optional)
    whitelist = True # bool | Whitelist (optional)
    search_type = 'search_type_example' # str | Search type (optional)
    fields = 'fields_example' # str | Comma-delimited list of fields to return (e.g. field_1,field_2,..). Leave blank to return all fields. (optional)
    sort_by = '-lastModifiedTime' # str | Sort order (optional) (default to '-lastModifiedTime')

    try:
        # Lists all accepted countries
        api_response = api_instance.get_acceptedcountries(count=count, start_index=start_index, name=name, whitelist=whitelist, search_type=search_type, fields=fields, sort_by=sort_by)
        print("The response of AcceptedCountriesApi->get_acceptedcountries:\n")
        pprint(api_response)
    except ApiException as e:
        print("Exception when calling AcceptedCountriesApi->get_acceptedcountries: %s\n" % e)

```

## Documentation for API Endpoints

All URIs are relative to */v3*

Class | Method | HTTP request | Description
------------ | ------------- | ------------- | -------------
*AcceptedCountriesApi* | [**get_acceptedcountries**](docs/AcceptedCountriesApi.md#get_acceptedcountries) | **GET** /acceptedcountries | Lists all accepted countries
*AcceptedCountriesApi* | [**get_acceptedcountries_token**](docs/AcceptedCountriesApi.md#get_acceptedcountries_token) | **GET** /acceptedcountries/{token} | Returns a specific accepted country
*AccountHolderGroupsApi* | [**get_accountholdergroups**](docs/AccountHolderGroupsApi.md#get_accountholdergroups) | **GET** /accountholdergroups | Lists account holder groups
*AccountHolderGroupsApi* | [**get_accountholdergroups_token**](docs/AccountHolderGroupsApi.md#get_accountholdergroups_token) | **GET** /accountholdergroups/{token} | Returns a specific account holder group object
*AccountHolderGroupsApi* | [**post_accountholdergroups**](docs/AccountHolderGroupsApi.md#post_accountholdergroups) | **POST** /accountholdergroups | Creates an account holder group object
*AccountHolderGroupsApi* | [**put_accountholdergroups_token**](docs/AccountHolderGroupsApi.md#put_accountholdergroups_token) | **PUT** /accountholdergroups/{token} | Updates an account holder group object
*AuthControlsApi* | [**get_authcontrols**](docs/AuthControlsApi.md#get_authcontrols) | **GET** /authcontrols | Lists all global auth control exceptions for the program
*AuthControlsApi* | [**get_authcontrols_exemptmids**](docs/AuthControlsApi.md#get_authcontrols_exemptmids) | **GET** /authcontrols/exemptmids | Lists all auth control exempted MIDs for the program
*AuthControlsApi* | [**get_authcontrols_exemptmids_token**](docs/AuthControlsApi.md#get_authcontrols_exemptmids_token) | **GET** /authcontrols/exemptmids/{token} | Returns a specific auth control exemptmids
*AuthControlsApi* | [**get_authcontrols_token**](docs/AuthControlsApi.md#get_authcontrols_token) | **GET** /authcontrols/{token} | Returns a specific auth control exception
*AuthControlsApi* | [**post_authcontrols**](docs/AuthControlsApi.md#post_authcontrols) | **POST** /authcontrols | Creates an auth control exception
*AuthControlsApi* | [**post_authcontrols_exemptmids**](docs/AuthControlsApi.md#post_authcontrols_exemptmids) | **POST** /authcontrols/exemptmids | Creates an auth control for exempting MIDs
*AuthControlsApi* | [**put_authcontrols_exemptmids_token**](docs/AuthControlsApi.md#put_authcontrols_exemptmids_token) | **PUT** /authcontrols/exemptmids/{token} | Updates the status an auth control exemptmids
*AuthControlsApi* | [**put_authcontrols_token**](docs/AuthControlsApi.md#put_authcontrols_token) | **PUT** /authcontrols/{token} | Updates an auth control exception
*AutoReloadsApi* | [**get_autoreloads**](docs/AutoReloadsApi.md#get_autoreloads) | **GET** /autoreloads | Lists all auto reloads for the program
*AutoReloadsApi* | [**get_autoreloads_token**](docs/AutoReloadsApi.md#get_autoreloads_token) | **GET** /autoreloads/{token} | Returns a specific auto reload object
*AutoReloadsApi* | [**post_autoreloads**](docs/AutoReloadsApi.md#post_autoreloads) | **POST** /autoreloads | Creates an auto reload object
*AutoReloadsApi* | [**put_autoreloads_token**](docs/AutoReloadsApi.md#put_autoreloads_token) | **PUT** /autoreloads/{token} | Updates a specific auto reload object
*BankTransfersApi* | [**get_banktransfers_ach**](docs/BankTransfersApi.md#get_banktransfers_ach) | **GET** /banktransfers/ach | Lists all bank transfers
*BankTransfersApi* | [**get_banktransfers_ach_token**](docs/BankTransfersApi.md#get_banktransfers_ach_token) | **GET** /banktransfers/ach/{token} | Returns a bank transfer entry
*BankTransfersApi* | [**get_banktransfers_ach_transitions**](docs/BankTransfersApi.md#get_banktransfers_ach_transitions) | **GET** /banktransfers/ach/transitions | Lists all bank transfer transitions
*BankTransfersApi* | [**post_apply_provisional_credit_to_bank_transfer**](docs/BankTransfersApi.md#post_apply_provisional_credit_to_bank_transfer) | **POST** /banktransfers/ach/earlyfunds | Applies a provisional credit to a bank transfer
*BankTransfersApi* | [**post_banktransfers_ach**](docs/BankTransfersApi.md#post_banktransfers_ach) | **POST** /banktransfers/ach | Creates an ACH bank transfer
*BankTransfersApi* | [**post_banktransfers_ach_transitions**](docs/BankTransfersApi.md#post_banktransfers_ach_transitions) | **POST** /banktransfers/ach/transitions | Creates an ACH bank transfer transition
*BulkIssuancesApi* | [**get_bulkissuances**](docs/BulkIssuancesApi.md#get_bulkissuances) | **GET** /bulkissuances | Lists all bulk issuance requests
*BulkIssuancesApi* | [**get_bulkissuances_token**](docs/BulkIssuancesApi.md#get_bulkissuances_token) | **GET** /bulkissuances/{token} | Returns a bulk issuance request
*BulkIssuancesApi* | [**post_bulkissuances**](docs/BulkIssuancesApi.md#post_bulkissuances) | **POST** /bulkissuances | Creates a bulk issuance request for cards
*BusinessTransitionsApi* | [**get_businesstransitions_business_businesstoken**](docs/BusinessTransitionsApi.md#get_businesstransitions_business_businesstoken) | **GET** /businesstransitions/business/{business_token} | Returns transitions for a given business
*BusinessTransitionsApi* | [**get_businesstransitions_token**](docs/BusinessTransitionsApi.md#get_businesstransitions_token) | **GET** /businesstransitions/{token} | Returns a business transition
*BusinessTransitionsApi* | [**post_businesstransitions**](docs/BusinessTransitionsApi.md#post_businesstransitions) | **POST** /businesstransitions | Creates a business transition
*BusinessesApi* | [**get_businesses**](docs/BusinessesApi.md#get_businesses) | **GET** /businesses | Lists all businesses
*BusinessesApi* | [**get_businesses_parenttoken_children**](docs/BusinessesApi.md#get_businesses_parenttoken_children) | **GET** /businesses/{parent_token}/children | Lists all children of a parent business
*BusinessesApi* | [**get_businesses_token**](docs/BusinessesApi.md#get_businesses_token) | **GET** /businesses/{token} | Returns a specific business
*BusinessesApi* | [**get_businesses_token_notes**](docs/BusinessesApi.md#get_businesses_token_notes) | **GET** /businesses/{token}/notes | Lists business notes
*BusinessesApi* | [**get_businesses_token_ssn**](docs/BusinessesApi.md#get_businesses_token_ssn) | **GET** /businesses/{token}/ssn | Returns a specific business proprietor&#39;s SSN
*BusinessesApi* | [**post_businesses**](docs/BusinessesApi.md#post_businesses) | **POST** /businesses | Creates a business
*BusinessesApi* | [**post_businesses_lookup**](docs/BusinessesApi.md#post_businesses_lookup) | **POST** /businesses/lookup | Returns a specific business
*BusinessesApi* | [**post_businesses_token_notes**](docs/BusinessesApi.md#post_businesses_token_notes) | **POST** /businesses/{token}/notes | Creates a note for a business
*BusinessesApi* | [**put_businesses_token**](docs/BusinessesApi.md#put_businesses_token) | **PUT** /businesses/{token} | Updates a specific business
*BusinessesApi* | [**put_businesses_token_notes_notestoken**](docs/BusinessesApi.md#put_businesses_token_notes_notestoken) | **PUT** /businesses/{token}/notes/{notes_token} | Updates a specific note for a business
*CardProductsApi* | [**get_cardproducts**](docs/CardProductsApi.md#get_cardproducts) | **GET** /cardproducts | Lists all card products
*CardProductsApi* | [**get_cardproducts_token**](docs/CardProductsApi.md#get_cardproducts_token) | **GET** /cardproducts/{token} | Returns a specific card product
*CardProductsApi* | [**post_cardproducts**](docs/CardProductsApi.md#post_cardproducts) | **POST** /cardproducts | Creates a card product
*CardProductsApi* | [**put_cardproducts_token**](docs/CardProductsApi.md#put_cardproducts_token) | **PUT** /cardproducts/{token} | Updates a specific card product
*CardTransitionsApi* | [**get_cardtransitions_card_token**](docs/CardTransitionsApi.md#get_cardtransitions_card_token) | **GET** /cardtransitions/card/{token} | Lists all card transitions
*CardTransitionsApi* | [**get_cardtransitions_token**](docs/CardTransitionsApi.md#get_cardtransitions_token) | **GET** /cardtransitions/{token} | Returns a card transition object
*CardTransitionsApi* | [**post_cardtransitions**](docs/CardTransitionsApi.md#post_cardtransitions) | **POST** /cardtransitions | Creates a card transition object
*CardholderBalancesApi* | [**get_balances_token**](docs/CardholderBalancesApi.md#get_balances_token) | **GET** /balances/{token} | Returns account balances for a cardholder
*CardholderBalancesApi* | [**get_balances_token_msas**](docs/CardholderBalancesApi.md#get_balances_token_msas) | **GET** /balances/{token}/msas | Returns a merchant-specific account balance
*CardholderBalancesApi* | [**get_high_yield_balances**](docs/CardholderBalancesApi.md#get_high_yield_balances) | **GET** /balances/{token}/highyield | Returns account balances for a high yield account
*CardsApi* | [**get_cards**](docs/CardsApi.md#get_cards) | **GET** /cards | Lists cards by the last 4 digits
*CardsApi* | [**get_cards_barcode_barcode**](docs/CardsApi.md#get_cards_barcode_barcode) | **GET** /cards/barcode/{barcode} | Returns a card&#39;s metadata
*CardsApi* | [**get_cards_card_hash_showpan**](docs/CardsApi.md#get_cards_card_hash_showpan) | **GET** /cards/{card_hash}/showpanbyhash | Returns a specific card - PAN visible
*CardsApi* | [**get_cards_merchant_merchanttoken**](docs/CardsApi.md#get_cards_merchant_merchanttoken) | **GET** /cards/merchant/{merchant_token} | Returns a merchant onboarding card
*CardsApi* | [**get_cards_merchant_merchanttoken_showpan**](docs/CardsApi.md#get_cards_merchant_merchanttoken_showpan) | **GET** /cards/merchant/{merchant_token}/showpan | Returns a specific card - PAN visible
*CardsApi* | [**get_cards_token**](docs/CardsApi.md#get_cards_token) | **GET** /cards/{token} | Returns a specific card
*CardsApi* | [**get_cards_token_showpan**](docs/CardsApi.md#get_cards_token_showpan) | **GET** /cards/{token}/showpan | Returns a specific card - PAN visible
*CardsApi* | [**get_cards_user_token**](docs/CardsApi.md#get_cards_user_token) | **GET** /cards/user/{token} | Lists all cards for a specific user
*CardsApi* | [**post_cards**](docs/CardsApi.md#post_cards) | **POST** /cards | Creates a card
*CardsApi* | [**post_cards_getbypan**](docs/CardsApi.md#post_cards_getbypan) | **POST** /cards/getbypan | Returns user and card tokens for the specified PAN
*CardsApi* | [**post_cards_merchant_merchanttoken**](docs/CardsApi.md#post_cards_merchant_merchanttoken) | **POST** /cards/merchant/{merchant_token} | Creates a merchant onboarding card
*CardsApi* | [**put_cards_token**](docs/CardsApi.md#put_cards_token) | **PUT** /cards/{token} | Updates a specific card
*ChargebacksApi* | [**get_chargebacks**](docs/ChargebacksApi.md#get_chargebacks) | **GET** /chargebacks | List all chargebacks
*ChargebacksApi* | [**get_chargebacks_chargebacktoken_transitions**](docs/ChargebacksApi.md#get_chargebacks_chargebacktoken_transitions) | **GET** /chargebacks/{chargeback_token}/transitions | Lists all chargeback transitions that are related to a chargeback
*ChargebacksApi* | [**get_chargebacks_token**](docs/ChargebacksApi.md#get_chargebacks_token) | **GET** /chargebacks/{token} | Returns a specific chargeback
*ChargebacksApi* | [**get_chargebacks_transitions_token**](docs/ChargebacksApi.md#get_chargebacks_transitions_token) | **GET** /chargebacks/transitions/{token} | Returns a specific chargeback transition
*ChargebacksApi* | [**post_chargeback_allocation_acknowledgment**](docs/ChargebacksApi.md#post_chargeback_allocation_acknowledgment) | **POST** /chargebacks/allocationacknowledgement | Creates a chargeback allocation acknowledgement
*ChargebacksApi* | [**post_chargebacks**](docs/ChargebacksApi.md#post_chargebacks) | **POST** /chargebacks | Creates a chargeback
*ChargebacksApi* | [**post_chargebacks_transitions**](docs/ChargebacksApi.md#post_chargebacks_transitions) | **POST** /chargebacks/transitions | Creates a chargeback transition
*ChargebacksApi* | [**put_chargebacks_token**](docs/ChargebacksApi.md#put_chargebacks_token) | **PUT** /chargebacks/{token} | Updates chargeback data
*ChargebacksApi* | [**put_chargebacks_token_grantprovisionalcredit**](docs/ChargebacksApi.md#put_chargebacks_token_grantprovisionalcredit) | **PUT** /chargebacks/{token}/grantprovisionalcredit | Grants provisional credit
*ChargebacksApi* | [**put_chargebacks_token_reverseprovisionalcredit**](docs/ChargebacksApi.md#put_chargebacks_token_reverseprovisionalcredit) | **PUT** /chargebacks/{token}/reverseprovisionalcredit | Reverses provisional credit
*CommandoModesApi* | [**get_commandomodes**](docs/CommandoModesApi.md#get_commandomodes) | **GET** /commandomodes | Lists all commando mode control sets
*CommandoModesApi* | [**get_commandomodes_commandomodetoken_transitions**](docs/CommandoModesApi.md#get_commandomodes_commandomodetoken_transitions) | **GET** /commandomodes/{commandomode_token}/transitions | Lists all commando mode transitions related to a commando mode control set
*CommandoModesApi* | [**get_commandomodes_token**](docs/CommandoModesApi.md#get_commandomodes_token) | **GET** /commandomodes/{token} | Returns a specific commando mode control set
*CommandoModesApi* | [**get_commandomodes_transitions_token**](docs/CommandoModesApi.md#get_commandomodes_transitions_token) | **GET** /commandomodes/transitions/{token} | Returns a specific commando mode transition
*DigitalWalletProvisionRequestsApi* | [**post_digitalwalletprovisionrequests_androidpay**](docs/DigitalWalletProvisionRequestsApi.md#post_digitalwalletprovisionrequests_androidpay) | **POST** /digitalwalletprovisionrequests/androidpay | Validates and creates Android-specific provisioning request data
*DigitalWalletProvisionRequestsApi* | [**post_digitalwalletprovisionrequests_applepay**](docs/DigitalWalletProvisionRequestsApi.md#post_digitalwalletprovisionrequests_applepay) | **POST** /digitalwalletprovisionrequests/applepay | Validates Apple certificates and creates Apple-specific provisioning request data
*DigitalWalletProvisionRequestsApi* | [**post_digitalwalletprovisionrequests_samsungpay**](docs/DigitalWalletProvisionRequestsApi.md#post_digitalwalletprovisionrequests_samsungpay) | **POST** /digitalwalletprovisionrequests/samsungpay | Validates and creates Samsung-specific provisioning request data
*DigitalWalletProvisionRequestsApi* | [**post_digitalwalletprovisionrequests_x_pay**](docs/DigitalWalletProvisionRequestsApi.md#post_digitalwalletprovisionrequests_x_pay) | **POST** /digitalwalletprovisionrequests/xpay | Validates and creates a generic push provisioning request data for adding a card to a digital wallet that is not ApplePay, GooglePay or SamsungPay.
*DigitalWalletTokenTransitionsApi* | [**get_digitalwallettokentransitions_digitalwallettoken_token**](docs/DigitalWalletTokenTransitionsApi.md#get_digitalwallettokentransitions_digitalwallettoken_token) | **GET** /digitalwallettokentransitions/digitalwallettoken/{token} | Lists all digital wallet token transitions
*DigitalWalletTokenTransitionsApi* | [**get_digitalwallettokentransitions_token**](docs/DigitalWalletTokenTransitionsApi.md#get_digitalwallettokentransitions_token) | **GET** /digitalwallettokentransitions/{token} | Returns a digital wallet transition object
*DigitalWalletTokenTransitionsApi* | [**post_digitalwallettokentransitions**](docs/DigitalWalletTokenTransitionsApi.md#post_digitalwallettokentransitions) | **POST** /digitalwallettokentransitions | Creates a digital wallet token transition
*DigitalWalletTokensApi* | [**get_digitalwallettokens**](docs/DigitalWalletTokensApi.md#get_digitalwallettokens) | **GET** /digitalwallettokens | Returns digital wallet tokens
*DigitalWalletTokensApi* | [**get_digitalwallettokens_card_cardtoken**](docs/DigitalWalletTokensApi.md#get_digitalwallettokens_card_cardtoken) | **GET** /digitalwallettokens/card/{card_token} | Returns a list of digital wallet tokens for the specified card
*DigitalWalletTokensApi* | [**get_digitalwallettokens_token**](docs/DigitalWalletTokensApi.md#get_digitalwallettokens_token) | **GET** /digitalwallettokens/{token} | Returns a specific digital wallet token
*DigitalWalletTokensApi* | [**get_digitalwallettokens_token_showtokenpan**](docs/DigitalWalletTokensApi.md#get_digitalwallettokens_token_showtokenpan) | **GET** /digitalwallettokens/{token}/showtokenpan | Returns a specific digital wallet token PAN visible
*DirectDepositAccountsApi* | [**create_account**](docs/DirectDepositAccountsApi.md#create_account) | **POST** /depositaccounts | Creates new direct deposit account for cardholder.
*DirectDepositAccountsApi* | [**create_transition**](docs/DirectDepositAccountsApi.md#create_transition) | **POST** /depositaccounts/transitions | Creates new transition for a direct deposit account.
*DirectDepositAccountsApi* | [**get_cdd_info**](docs/DirectDepositAccountsApi.md#get_cdd_info) | **GET** /depositaccounts/{token}/cdd | Get direct deposit account transition list for card holder.
*DirectDepositAccountsApi* | [**get_direct_deposit_account**](docs/DirectDepositAccountsApi.md#get_direct_deposit_account) | **GET** /depositaccounts/{token} | Get direct deposit account.
*DirectDepositAccountsApi* | [**get_direct_deposit_account_transition**](docs/DirectDepositAccountsApi.md#get_direct_deposit_account_transition) | **GET** /depositaccounts/transitions/{token} | Get direct deposit account transition.
*DirectDepositAccountsApi* | [**get_transition_list**](docs/DirectDepositAccountsApi.md#get_transition_list) | **GET** /depositaccounts/{user_token}/transitions | Get direct deposit account transition list for card holder.
*DirectDepositAccountsApi* | [**get_user_direct_deposit_accounts**](docs/DirectDepositAccountsApi.md#get_user_direct_deposit_accounts) | **GET** /depositaccounts/user/{token} | List all specific direct deposit accounts.
*DirectDepositAccountsApi* | [**get_user_for_direct_deposit_account**](docs/DirectDepositAccountsApi.md#get_user_for_direct_deposit_account) | **GET** /depositaccounts/account/{account_number}/user | Get User for Plain Text Account Number
*DirectDepositAccountsApi* | [**update**](docs/DirectDepositAccountsApi.md#update) | **PUT** /depositaccounts/{token} | Update direct deposit account.
*DirectDepositAccountsApi* | [**update_cdd_info**](docs/DirectDepositAccountsApi.md#update_cdd_info) | **PUT** /depositaccounts/{token}/cdd/{cddtoken} | Update CDD answers for Direct Deposit Account
*DirectDepositsApi* | [**get_directdeposits**](docs/DirectDepositsApi.md#get_directdeposits) | **GET** /directdeposits | Lists all direct deposits
*DirectDepositsApi* | [**get_directdeposits_accounts_userorbusinesstoken**](docs/DirectDepositsApi.md#get_directdeposits_accounts_userorbusinesstoken) | **GET** /directdeposits/accounts/{user_or_business_token} | Returns an account and routing number which can be used for direct deposit
*DirectDepositsApi* | [**get_directdeposits_token**](docs/DirectDepositsApi.md#get_directdeposits_token) | **GET** /directdeposits/{token} | Returns a direct deposit entry
*DirectDepositsApi* | [**get_directdeposits_transitions**](docs/DirectDepositsApi.md#get_directdeposits_transitions) | **GET** /directdeposits/transitions | Returns a list of direct deposit transitions
*DirectDepositsApi* | [**get_directdeposits_transitions_token**](docs/DirectDepositsApi.md#get_directdeposits_transitions_token) | **GET** /directdeposits/transitions/{token} | Returns a direct deposit transition
*DirectDepositsApi* | [**post_directdeposits_transitions**](docs/DirectDepositsApi.md#post_directdeposits_transitions) | **POST** /directdeposits/transitions | Creates a direct deposit transition
*DirectDepositsApi* | [**put_directdeposits_accounts_userorbusinesstoken**](docs/DirectDepositsApi.md#put_directdeposits_accounts_userorbusinesstoken) | **PUT** /directdeposits/accounts/{user_or_business_token} | Updates a specific direct deposit account
*FeeTransfersApi* | [**get_feetransfers_token**](docs/FeeTransfersApi.md#get_feetransfers_token) | **GET** /feetransfers/{token} | Returns a fee transfer
*FeeTransfersApi* | [**post_feetransfers**](docs/FeeTransfersApi.md#post_feetransfers) | **POST** /feetransfers | Creates a fee transfer
*FeesApi* | [**get_fees**](docs/FeesApi.md#get_fees) | **GET** /fees | Lists all fees
*FeesApi* | [**get_fees_token**](docs/FeesApi.md#get_fees_token) | **GET** /fees/{token} | Returns a specific fee
*FeesApi* | [**post_fees**](docs/FeesApi.md#post_fees) | **POST** /fees | Creates a fee
*FeesApi* | [**put_fees_token**](docs/FeesApi.md#put_fees_token) | **PUT** /fees/{token} | Updates a specific fee
*FundingSourcesApi* | [**get_ach_partner_linked_funding_source_balance**](docs/FundingSourcesApi.md#get_ach_partner_linked_funding_source_balance) | **GET** /fundingsources/ach/partner/{funding_source_token}/balance | Retrieves a linked funding source balance from a partner
*FundingSourcesApi* | [**get_all_ach_funding_sources**](docs/FundingSourcesApi.md#get_all_ach_funding_sources) | **GET** /fundingsources/program/ach | Returns a list of Program ACH funding sources
*FundingSourcesApi* | [**get_fundingsources_ach_fundingsourcetoken**](docs/FundingSourcesApi.md#get_fundingsources_ach_fundingsourcetoken) | **GET** /fundingsources/ach/{funding_source_token} | Returns a user ACH account
*FundingSourcesApi* | [**get_fundingsources_ach_fundingsourcetoken_verificationamounts**](docs/FundingSourcesApi.md#get_fundingsources_ach_fundingsourcetoken_verificationamounts) | **GET** /fundingsources/ach/{funding_source_token}/verificationamounts | Returns the dollar amounts used to verify the ACH account
*FundingSourcesApi* | [**get_fundingsources_addresses_business_businesstoken**](docs/FundingSourcesApi.md#get_fundingsources_addresses_business_businesstoken) | **GET** /fundingsources/addresses/business/{business_token} | Lists all addresses for a business
*FundingSourcesApi* | [**get_fundingsources_addresses_fundingsourceaddresstoken**](docs/FundingSourcesApi.md#get_fundingsources_addresses_fundingsourceaddresstoken) | **GET** /fundingsources/addresses/{funding_source_address_token} | Returns a user address for a funding source
*FundingSourcesApi* | [**get_fundingsources_addresses_user_usertoken**](docs/FundingSourcesApi.md#get_fundingsources_addresses_user_usertoken) | **GET** /fundingsources/addresses/user/{user_token} | Lists all addresses for a user
*FundingSourcesApi* | [**get_fundingsources_business_businesstoken**](docs/FundingSourcesApi.md#get_fundingsources_business_businesstoken) | **GET** /fundingsources/business/{business_token} | Lists all funding sources for a business
*FundingSourcesApi* | [**get_fundingsources_paymentcard_fundingsourcetoken**](docs/FundingSourcesApi.md#get_fundingsources_paymentcard_fundingsourcetoken) | **GET** /fundingsources/paymentcard/{funding_source_token} | Returns a specific payment card
*FundingSourcesApi* | [**get_fundingsources_program_token**](docs/FundingSourcesApi.md#get_fundingsources_program_token) | **GET** /fundingsources/program/{token} | Returns a specific program funding source
*FundingSourcesApi* | [**get_fundingsources_programgateway_token**](docs/FundingSourcesApi.md#get_fundingsources_programgateway_token) | **GET** /fundingsources/programgateway/{token} | Returns a gateway program funding source
*FundingSourcesApi* | [**get_fundingsources_user_usertoken**](docs/FundingSourcesApi.md#get_fundingsources_user_usertoken) | **GET** /fundingsources/user/{user_token} | Lists all funding sources for a user
*FundingSourcesApi* | [**post_fundingsources_ach**](docs/FundingSourcesApi.md#post_fundingsources_ach) | **POST** /fundingsources/ach | Registers an ACH funding source
*FundingSourcesApi* | [**post_fundingsources_ach_partner**](docs/FundingSourcesApi.md#post_fundingsources_ach_partner) | **POST** /fundingsources/ach/partner | Registers an ACH funding source through a partner
*FundingSourcesApi* | [**post_fundingsources_addresses**](docs/FundingSourcesApi.md#post_fundingsources_addresses) | **POST** /fundingsources/addresses | Creates an account holder address for a funding source
*FundingSourcesApi* | [**post_fundingsources_paymentcard**](docs/FundingSourcesApi.md#post_fundingsources_paymentcard) | **POST** /fundingsources/paymentcard | Registers a payment card funding source
*FundingSourcesApi* | [**post_fundingsources_program**](docs/FundingSourcesApi.md#post_fundingsources_program) | **POST** /fundingsources/program | Creates a program funding source
*FundingSourcesApi* | [**post_fundingsources_program_ach**](docs/FundingSourcesApi.md#post_fundingsources_program_ach) | **POST** /fundingsources/program/ach | Registers an ACH funding source for a program
*FundingSourcesApi* | [**post_fundingsources_programgateway**](docs/FundingSourcesApi.md#post_fundingsources_programgateway) | **POST** /fundingsources/programgateway | Creates a gateway program funding source
*FundingSourcesApi* | [**put_fundingsources_ach_fundingsourcetoken**](docs/FundingSourcesApi.md#put_fundingsources_ach_fundingsourcetoken) | **PUT** /fundingsources/ach/{funding_source_token} | Verifies a bank account as a funding source
*FundingSourcesApi* | [**put_fundingsources_addresses_fundingsourceaddresstoken**](docs/FundingSourcesApi.md#put_fundingsources_addresses_fundingsourceaddresstoken) | **PUT** /fundingsources/addresses/{funding_source_address_token} | Updates the account holder address for a funding source
*FundingSourcesApi* | [**put_fundingsources_fundingsourcetoken**](docs/FundingSourcesApi.md#put_fundingsources_fundingsourcetoken) | **PUT** /fundingsources/paymentcard/{funding_source_token} | Updates a specific payment card 
*FundingSourcesApi* | [**put_fundingsources_fundingsourcetoken_default**](docs/FundingSourcesApi.md#put_fundingsources_fundingsourcetoken_default) | **PUT** /fundingsources/{funding_source_token}/default | Configures a default funding source
*FundingSourcesApi* | [**put_fundingsources_program_token**](docs/FundingSourcesApi.md#put_fundingsources_program_token) | **PUT** /fundingsources/program/{token} | Updates a specific program funding source
*FundingSourcesApi* | [**put_fundingsources_programgateway_custom_header_token**](docs/FundingSourcesApi.md#put_fundingsources_programgateway_custom_header_token) | **PUT** /fundingsources/programgateway/customheaders/{token} | Updates a specific gateway program funding source Custom headers
*FundingSourcesApi* | [**put_fundingsources_programgateway_token**](docs/FundingSourcesApi.md#put_fundingsources_programgateway_token) | **PUT** /fundingsources/programgateway/{token} | Updates a specific gateway program funding source
*GpaOrdersApi* | [**get_gpaorders_token**](docs/GpaOrdersApi.md#get_gpaorders_token) | **GET** /gpaorders/{token} | Returns a GPA order
*GpaOrdersApi* | [**get_gpaorders_unloads**](docs/GpaOrdersApi.md#get_gpaorders_unloads) | **GET** /gpaorders/unloads | Lists all GPA returns
*GpaOrdersApi* | [**get_gpaorders_unloads_unloadtoken**](docs/GpaOrdersApi.md#get_gpaorders_unloads_unloadtoken) | **GET** /gpaorders/unloads/{unload_token} | Returns a specific GPA return
*GpaOrdersApi* | [**post_gpaorders**](docs/GpaOrdersApi.md#post_gpaorders) | **POST** /gpaorders | Funds a user&#39;s GPA account
*GpaOrdersApi* | [**post_gpaorders_unloads**](docs/GpaOrdersApi.md#post_gpaorders_unloads) | **POST** /gpaorders/unloads | Returns a GPA order
*KycApi* | [**get_kyc_business_businesstoken**](docs/KycApi.md#get_kyc_business_businesstoken) | **GET** /kyc/business/{business_token} | Lists all KYC results for a business
*KycApi* | [**get_kyc_token**](docs/KycApi.md#get_kyc_token) | **GET** /kyc/{token} | Returns a specific KYC result
*KycApi* | [**get_kyc_user_usertoken**](docs/KycApi.md#get_kyc_user_usertoken) | **GET** /kyc/user/{user_token} | Lists all KYC results for a user
*KycApi* | [**post_kyc**](docs/KycApi.md#post_kyc) | **POST** /kyc | Performs a KYC
*KycApi* | [**put_kyc_token**](docs/KycApi.md#put_kyc_token) | **PUT** /kyc/{token} | Accepts KYC answers for questions from initial request
*MccGroupsApi* | [**get_mccgroups**](docs/MccGroupsApi.md#get_mccgroups) | **GET** /mccgroups | Lists all MCC groups
*MccGroupsApi* | [**get_mccgroups_token**](docs/MccGroupsApi.md#get_mccgroups_token) | **GET** /mccgroups/{token} | Returns a specific MCC group
*MccGroupsApi* | [**post_mccgroups**](docs/MccGroupsApi.md#post_mccgroups) | **POST** /mccgroups | Creates an MCC group
*MccGroupsApi* | [**put_mccgroups_token**](docs/MccGroupsApi.md#put_mccgroups_token) | **PUT** /mccgroups/{token} | Updates an MCC group
*MerchantgroupsApi* | [**get_merchant_group**](docs/MerchantgroupsApi.md#get_merchant_group) | **GET** /merchantgroups/{token} | Returns a Merchant Group
*MerchantgroupsApi* | [**get_merchant_groups**](docs/MerchantgroupsApi.md#get_merchant_groups) | **GET** /merchantgroups | Lists all Merchant Groups
*MerchantgroupsApi* | [**post_merchant_group**](docs/MerchantgroupsApi.md#post_merchant_group) | **POST** /merchantgroups | Creates a merchant group
*MerchantgroupsApi* | [**put_merchant_groups_token**](docs/MerchantgroupsApi.md#put_merchant_groups_token) | **PUT** /merchantgroups/{token} | Updates an Merchant Group
*PeerTransfersApi* | [**get_peertransfers_token**](docs/PeerTransfersApi.md#get_peertransfers_token) | **GET** /peertransfers/{token} | Returns details of a previous transfer
*PeerTransfersApi* | [**get_peertransfers_user_userorbusinesstoken**](docs/PeerTransfersApi.md#get_peertransfers_user_userorbusinesstoken) | **GET** /peertransfers/user/{user_or_business_token} | Returns all peer transfers for a user
*PeerTransfersApi* | [**get_peertransfers_user_userorbusinesstoken_recipient**](docs/PeerTransfersApi.md#get_peertransfers_user_userorbusinesstoken_recipient) | **GET** /peertransfers/user/{user_or_business_token}/recipient | Returns received peer transfers for a user
*PeerTransfersApi* | [**get_peertransfers_user_userorbusinesstoken_sender**](docs/PeerTransfersApi.md#get_peertransfers_user_userorbusinesstoken_sender) | **GET** /peertransfers/user/{user_or_business_token}/sender | Returns sent peer transfers for a user
*PeerTransfersApi* | [**post_peertransfers**](docs/PeerTransfersApi.md#post_peertransfers) | **POST** /peertransfers | Performs a peer transfer from one user to another
*PingApi* | [**get_ping**](docs/PingApi.md#get_ping) | **GET** /ping | Returns a heartbeat to the consumer
*PingApi* | [**post_ping**](docs/PingApi.md#post_ping) | **POST** /ping | Echo test for sending payload to server
*PinsApi* | [**post_pins_controltoken**](docs/PinsApi.md#post_pins_controltoken) | **POST** /pins/controltoken | Creates a new control token for a PIN
*PinsApi* | [**put_pins**](docs/PinsApi.md#put_pins) | **PUT** /pins | Updates the PIN control token
*PinsApi* | [**reveal_pins**](docs/PinsApi.md#reveal_pins) | **POST** /pins/reveal | Updates the PIN-reveal control token
*ProgramReserveApi* | [**deposit**](docs/ProgramReserveApi.md#deposit) | **POST** /programreserve/deposits | 
*ProgramReserveApi* | [**get_program_reserve_deposits**](docs/ProgramReserveApi.md#get_program_reserve_deposits) | **GET** /programreserve/deposits | 
*ProgramReserveApi* | [**get_programreserve_balances**](docs/ProgramReserveApi.md#get_programreserve_balances) | **GET** /programreserve/balances | Returns the latest balance in the program reserve account
*ProgramReserveApi* | [**get_programreserve_transactions**](docs/ProgramReserveApi.md#get_programreserve_transactions) | **GET** /programreserve/transactions | Returns a list of program reserve transactions (credits and debits)
*ProgramReserveApi* | [**post_programreserve_transactions**](docs/ProgramReserveApi.md#post_programreserve_transactions) | **POST** /programreserve/transactions | Credits or debits the program reserve account
*ProgramTransfersApi* | [**get_programtransfers**](docs/ProgramTransfersApi.md#get_programtransfers) | **GET** /programtransfers | Lists all program transfers
*ProgramTransfersApi* | [**get_programtransfers_token**](docs/ProgramTransfersApi.md#get_programtransfers_token) | **GET** /programtransfers/{token} | Returns a specific program transfer
*ProgramTransfersApi* | [**get_programtransfers_types**](docs/ProgramTransfersApi.md#get_programtransfers_types) | **GET** /programtransfers/types | Lists all program transfer types
*ProgramTransfersApi* | [**get_programtransfers_types_typetoken**](docs/ProgramTransfersApi.md#get_programtransfers_types_typetoken) | **GET** /programtransfers/types/{type_token} | Returns a specific program transfer type
*ProgramTransfersApi* | [**post_programtransfers**](docs/ProgramTransfersApi.md#post_programtransfers) | **POST** /programtransfers | Transfers to a program funding source
*ProgramTransfersApi* | [**post_programtransfers_types**](docs/ProgramTransfersApi.md#post_programtransfers_types) | **POST** /programtransfers/types | Creates a program transfer type
*ProgramTransfersApi* | [**put_programtransfers_types_typetoken**](docs/ProgramTransfersApi.md#put_programtransfers_types_typetoken) | **PUT** /programtransfers/types/{type_token} | Updates a specific program transfer type
*PushToCardApi* | [**get_pushtocards_disburse**](docs/PushToCardApi.md#get_pushtocards_disburse) | **GET** /pushtocards/disburse | Lists all push-to-card disbursements
*PushToCardApi* | [**get_pushtocards_disburse_token**](docs/PushToCardApi.md#get_pushtocards_disburse_token) | **GET** /pushtocards/disburse/{token} | Returns a specific push-to-card disbursement
*PushToCardApi* | [**get_pushtocards_paymentcard**](docs/PushToCardApi.md#get_pushtocards_paymentcard) | **GET** /pushtocards/paymentcard | Returns all push-to-card payment card details
*PushToCardApi* | [**get_pushtocards_paymentcard_token**](docs/PushToCardApi.md#get_pushtocards_paymentcard_token) | **GET** /pushtocards/paymentcard/{token} | Returns a specific paymentcard object
*PushToCardApi* | [**post_pushtocards_disburse**](docs/PushToCardApi.md#post_pushtocards_disburse) | **POST** /pushtocards/disburse | Initiates a push-to-card money disbursement
*PushToCardApi* | [**post_pushtocards_paymentcard**](docs/PushToCardApi.md#post_pushtocards_paymentcard) | **POST** /pushtocards/paymentcard | Adds an external card to which funds will be pushed
*RealTimeFeeGroupsApi* | [**get_realtimefeegroups**](docs/RealTimeFeeGroupsApi.md#get_realtimefeegroups) | **GET** /realtimefeegroups | Lists all real-time fee groups
*RealTimeFeeGroupsApi* | [**get_realtimefeegroups_token**](docs/RealTimeFeeGroupsApi.md#get_realtimefeegroups_token) | **GET** /realtimefeegroups/{token} | Returns a specific real-time fee group
*RealTimeFeeGroupsApi* | [**post_realtimefeegroups**](docs/RealTimeFeeGroupsApi.md#post_realtimefeegroups) | **POST** /realtimefeegroups | Creates a real-time fee group
*RealTimeFeeGroupsApi* | [**put_realtimefeegroups_token**](docs/RealTimeFeeGroupsApi.md#put_realtimefeegroups_token) | **PUT** /realtimefeegroups/{token} | Updates a specific real-time fee group
*SimulateApi* | [**post_simulate_authorization**](docs/SimulateApi.md#post_simulate_authorization) | **POST** /simulate/authorization | Simulates an authorization
*SimulateApi* | [**post_simulate_authorization_advice**](docs/SimulateApi.md#post_simulate_authorization_advice) | **POST** /simulate/authorization/advice | Simulates an authorization advice transaction
*SimulateApi* | [**post_simulate_clearing**](docs/SimulateApi.md#post_simulate_clearing) | **POST** /simulate/clearing | Simulates a clearing/settlement transaction
*SimulateApi* | [**post_simulate_directdeposits**](docs/SimulateApi.md#post_simulate_directdeposits) | **POST** /simulate/directdeposits | Simulates the creation of direct deposit
*SimulateApi* | [**post_simulate_financial**](docs/SimulateApi.md#post_simulate_financial) | **POST** /simulate/financial | Simulates a financial request (PIN debit) transaction with optional cash back
*SimulateApi* | [**post_simulate_financial_advice**](docs/SimulateApi.md#post_simulate_financial_advice) | **POST** /simulate/financial/advice | Simulates a financial advice transaction
*SimulateApi* | [**post_simulate_financial_balanceinquiry**](docs/SimulateApi.md#post_simulate_financial_balanceinquiry) | **POST** /simulate/financial/balanceinquiry | Simulates a balance inquiry
*SimulateApi* | [**post_simulate_financial_originalcredit**](docs/SimulateApi.md#post_simulate_financial_originalcredit) | **POST** /simulate/financial/originalcredit | Simulates an orignal credit transaction
*SimulateApi* | [**post_simulate_financial_withdrawal**](docs/SimulateApi.md#post_simulate_financial_withdrawal) | **POST** /simulate/financial/withdrawal | Simulates an ATM withdrawal transaction
*SimulateApi* | [**post_simulate_reversal**](docs/SimulateApi.md#post_simulate_reversal) | **POST** /simulate/reversal | Simulates a reversal transaction
*TransactionsApi* | [**get_transactions**](docs/TransactionsApi.md#get_transactions) | **GET** /transactions | Returns transactions
*TransactionsApi* | [**get_transactions_fundingsource_fundingsourcetoken**](docs/TransactionsApi.md#get_transactions_fundingsource_fundingsourcetoken) | **GET** /transactions/fundingsource/{funding_source_token} | Returns transactions for a specific funding account
*TransactionsApi* | [**get_transactions_token**](docs/TransactionsApi.md#get_transactions_token) | **GET** /transactions/{token} | Returns a transaction
*TransactionsApi* | [**get_transactions_token_related**](docs/TransactionsApi.md#get_transactions_token_related) | **GET** /transactions/{token}/related | Returns related transactions
*UserTransitionsApi* | [**get_usertransitions_token**](docs/UserTransitionsApi.md#get_usertransitions_token) | **GET** /usertransitions/{token} | Returns a user transition
*UserTransitionsApi* | [**get_usertransitions_user_usertoken**](docs/UserTransitionsApi.md#get_usertransitions_user_usertoken) | **GET** /usertransitions/user/{user_token} | Returns transitions for a specific user
*UserTransitionsApi* | [**post_usertransitions**](docs/UserTransitionsApi.md#post_usertransitions) | **POST** /usertransitions | Creates a user transition
*UsersApi* | [**get_users**](docs/UsersApi.md#get_users) | **GET** /users | Lists all users
*UsersApi* | [**get_users_auth_clientaccesstoken_token**](docs/UsersApi.md#get_users_auth_clientaccesstoken_token) | **GET** /users/auth/clientaccesstoken/{token} | Returns a client access token
*UsersApi* | [**get_users_parenttoken_children**](docs/UsersApi.md#get_users_parenttoken_children) | **GET** /users/{parent_token}/children | Lists all children of a parent user
*UsersApi* | [**get_users_phonenumber_phonenumber**](docs/UsersApi.md#get_users_phonenumber_phonenumber) | **GET** /users/phonenumber/{phone_number} | Lists all users who match a phone number
*UsersApi* | [**get_users_token**](docs/UsersApi.md#get_users_token) | **GET** /users/{token} | Returns a specific user
*UsersApi* | [**get_users_token_notes**](docs/UsersApi.md#get_users_token_notes) | **GET** /users/{token}/notes | Lists cardholder notes
*UsersApi* | [**get_users_token_ssn**](docs/UsersApi.md#get_users_token_ssn) | **GET** /users/{token}/ssn | Returns a specific user&#39;s SSN
*UsersApi* | [**post_users**](docs/UsersApi.md#post_users) | **POST** /users | Creates a user
*UsersApi* | [**post_users_auth_changepassword**](docs/UsersApi.md#post_users_auth_changepassword) | **POST** /users/auth/changepassword | Updates a user password
*UsersApi* | [**post_users_auth_clientaccesstoken**](docs/UsersApi.md#post_users_auth_clientaccesstoken) | **POST** /users/auth/clientaccesstoken | Creates a client access token
*UsersApi* | [**post_users_auth_login**](docs/UsersApi.md#post_users_auth_login) | **POST** /users/auth/login | Logs in a user
*UsersApi* | [**post_users_auth_logout**](docs/UsersApi.md#post_users_auth_logout) | **POST** /users/auth/logout | Logs out a user
*UsersApi* | [**post_users_auth_onetime**](docs/UsersApi.md#post_users_auth_onetime) | **POST** /users/auth/onetime | Creates a one-time token
*UsersApi* | [**post_users_auth_resetpassword**](docs/UsersApi.md#post_users_auth_resetpassword) | **POST** /users/auth/resetpassword | Generates a reset password email
*UsersApi* | [**post_users_auth_resetpassword_token**](docs/UsersApi.md#post_users_auth_resetpassword_token) | **POST** /users/auth/resetpassword/{token} | Resets a user password
*UsersApi* | [**post_users_auth_verifyemail**](docs/UsersApi.md#post_users_auth_verifyemail) | **POST** /users/auth/verifyemail | Generates an email verification request
*UsersApi* | [**post_users_auth_verifyemail_token**](docs/UsersApi.md#post_users_auth_verifyemail_token) | **POST** /users/auth/verifyemail/{token} | Verifies the email token
*UsersApi* | [**post_users_lookup**](docs/UsersApi.md#post_users_lookup) | **POST** /users/lookup | Lists all users
*UsersApi* | [**post_users_token_notes**](docs/UsersApi.md#post_users_token_notes) | **POST** /users/{token}/notes | Creates a note for the cardholder
*UsersApi* | [**put_users_token**](docs/UsersApi.md#put_users_token) | **PUT** /users/{token} | Updates a specific user
*UsersApi* | [**put_users_token_notes_notestoken**](docs/UsersApi.md#put_users_token_notes_notestoken) | **PUT** /users/{token}/notes/{notes_token} | Updates a specific note for a cardholder
*VelocityControlsApi* | [**get_velocitycontrols**](docs/VelocityControlsApi.md#get_velocitycontrols) | **GET** /velocitycontrols | Queries velocity controls
*VelocityControlsApi* | [**get_velocitycontrols_token**](docs/VelocityControlsApi.md#get_velocitycontrols_token) | **GET** /velocitycontrols/{token} | Returns a specific velocity control
*VelocityControlsApi* | [**get_velocitycontrols_user_usertoken_available**](docs/VelocityControlsApi.md#get_velocitycontrols_user_usertoken_available) | **GET** /velocitycontrols/user/{user_token}/available | Queries a user&#39;s velocity control balances
*VelocityControlsApi* | [**post_velocitycontrols**](docs/VelocityControlsApi.md#post_velocitycontrols) | **POST** /velocitycontrols | Creates a velocity control
*VelocityControlsApi* | [**put_velocitycontrols_token**](docs/VelocityControlsApi.md#put_velocitycontrols_token) | **PUT** /velocitycontrols/{token} | Updates a specific velocity control
*WebPushProvisioningApi* | [**generate_apple_pay_wppjwt**](docs/WebPushProvisioningApi.md#generate_apple_pay_wppjwt) | **POST** /digitalwallets/wpp/applePayJWT | API to generate a Javascript object token containing a JWT to initiate Apple Pay web push provisioning
*WebPushProvisioningApi* | [**get_wpp_parameters**](docs/WebPushProvisioningApi.md#get_wpp_parameters) | **POST** /digitalwallets/wpp/parameters | API to query for the web push provisioning related parameters, such as: google piaid/integrator_id, apple partnerId, apple Card Template Identifier
*WebPushProvisioningApi* | [**send_opc_data_to_google_pay**](docs/WebPushProvisioningApi.md#send_opc_data_to_google_pay) | **POST** /digitalwallets/wpp/googlePayPushProvisioningNotification | Request sending OPC data to google pay
*WebhooksApi* | [**get_webhooks**](docs/WebhooksApi.md#get_webhooks) | **GET** /webhooks | Returns a list of webhook configurations
*WebhooksApi* | [**get_webhooks_token**](docs/WebhooksApi.md#get_webhooks_token) | **GET** /webhooks/{token} | Returns a webhook configuration
*WebhooksApi* | [**post_webhooks**](docs/WebhooksApi.md#post_webhooks) | **POST** /webhooks | Creates a webhook configuration
*WebhooksApi* | [**post_webhooks_token_eventtype_eventtoken**](docs/WebhooksApi.md#post_webhooks_token_eventtype_eventtoken) | **POST** /webhooks/{token}/{event_type}/{event_token} | Replays an event to a webhook
*WebhooksApi* | [**post_webhooks_token_ping**](docs/WebhooksApi.md#post_webhooks_token_ping) | **POST** /webhooks/{token}/ping | Pings a webhook
*WebhooksApi* | [**put_webhooks_custom_headers_token**](docs/WebhooksApi.md#put_webhooks_custom_headers_token) | **PUT** /webhooks/customheaders/{token} | Updates a specific webhook configuration with custom headers
*WebhooksApi* | [**put_webhooks_token**](docs/WebhooksApi.md#put_webhooks_token) | **PUT** /webhooks/{token} | Updates a specific webhook configuration


## Documentation For Models

 - [ACHListResponse](docs/ACHListResponse.md)
 - [ACHReturn](docs/ACHReturn.md)
 - [ACHReversalRequest](docs/ACHReversalRequest.md)
 - [ATCInformationModel](docs/ATCInformationModel.md)
 - [AcceptedCountriesListResponse](docs/AcceptedCountriesListResponse.md)
 - [AcceptedCountriesModel](docs/AcceptedCountriesModel.md)
 - [AcceptedCountriesUpdateModel](docs/AcceptedCountriesUpdateModel.md)
 - [AccessTokenResponse](docs/AccessTokenResponse.md)
 - [Account](docs/Account.md)
 - [AccountFunding](docs/AccountFunding.md)
 - [AccountFundingReceiverData](docs/AccountFundingReceiverData.md)
 - [AccountFundingRequest](docs/AccountFundingRequest.md)
 - [AccountHolderGroupConfig](docs/AccountHolderGroupConfig.md)
 - [AccountHolderGroupListResponse](docs/AccountHolderGroupListResponse.md)
 - [AccountHolderGroupRequest](docs/AccountHolderGroupRequest.md)
 - [AccountHolderGroupResponse](docs/AccountHolderGroupResponse.md)
 - [AccountHolderGroupUpdateRequest](docs/AccountHolderGroupUpdateRequest.md)
 - [AccountModel](docs/AccountModel.md)
 - [AchModel](docs/AchModel.md)
 - [AchPartnerRequestModel](docs/AchPartnerRequestModel.md)
 - [AchResponseModel](docs/AchResponseModel.md)
 - [AchVerificationModel](docs/AchVerificationModel.md)
 - [Acquirer](docs/Acquirer.md)
 - [ActivationActions](docs/ActivationActions.md)
 - [AddressRequestModel](docs/AddressRequestModel.md)
 - [AddressResponseModel](docs/AddressResponseModel.md)
 - [AddressVerification](docs/AddressVerification.md)
 - [AddressVerificationModel](docs/AddressVerificationModel.md)
 - [AddressVerificationSource](docs/AddressVerificationSource.md)
 - [AdvAuthRequestModel](docs/AdvAuthRequestModel.md)
 - [AdvancedAuthCardAcceptorModel](docs/AdvancedAuthCardAcceptorModel.md)
 - [AdvancedAuthCardOptions](docs/AdvancedAuthCardOptions.md)
 - [AdvancedAuthOtherPOI](docs/AdvancedAuthOtherPOI.md)
 - [AdvancedAuthPOI](docs/AdvancedAuthPOI.md)
 - [AdvancedClearingRequestModel](docs/AdvancedClearingRequestModel.md)
 - [AdvancedSimulationResponseModel](docs/AdvancedSimulationResponseModel.md)
 - [AdviceRequestModel](docs/AdviceRequestModel.md)
 - [Airline](docs/Airline.md)
 - [AndroidPushTokenRequestAddress](docs/AndroidPushTokenRequestAddress.md)
 - [AndroidPushTokenizeRequestData](docs/AndroidPushTokenizeRequestData.md)
 - [Application](docs/Application.md)
 - [AuthControlExemptMidsListResponse](docs/AuthControlExemptMidsListResponse.md)
 - [AuthControlExemptMidsRequest](docs/AuthControlExemptMidsRequest.md)
 - [AuthControlExemptMidsResponse](docs/AuthControlExemptMidsResponse.md)
 - [AuthControlExemptMidsUpdateRequest](docs/AuthControlExemptMidsUpdateRequest.md)
 - [AuthControlListResponse](docs/AuthControlListResponse.md)
 - [AuthControlMerchantScope](docs/AuthControlMerchantScope.md)
 - [AuthControlRequest](docs/AuthControlRequest.md)
 - [AuthControlResponse](docs/AuthControlResponse.md)
 - [AuthControlUpdateRequest](docs/AuthControlUpdateRequest.md)
 - [AuthControls](docs/AuthControls.md)
 - [AuthRequestModel](docs/AuthRequestModel.md)
 - [AuthUser](docs/AuthUser.md)
 - [AuthUserRequest](docs/AuthUserRequest.md)
 - [AuthUserUpdateRequest](docs/AuthUserUpdateRequest.md)
 - [Authentication](docs/Authentication.md)
 - [AuthorizationAdviceModel](docs/AuthorizationAdviceModel.md)
 - [AutoCommandoModeProgramFundingSourceResponse](docs/AutoCommandoModeProgramFundingSourceResponse.md)
 - [AutoCommandoModeRequest](docs/AutoCommandoModeRequest.md)
 - [AutoCommandoModeResponse](docs/AutoCommandoModeResponse.md)
 - [AutoReloadAssociation](docs/AutoReloadAssociation.md)
 - [AutoReloadListResponse](docs/AutoReloadListResponse.md)
 - [AutoReloadModel](docs/AutoReloadModel.md)
 - [AutoReloadResponseModel](docs/AutoReloadResponseModel.md)
 - [AutoReloadUpdateModel](docs/AutoReloadUpdateModel.md)
 - [Available](docs/Available.md)
 - [AvsControlOptions](docs/AvsControlOptions.md)
 - [AvsControls](docs/AvsControls.md)
 - [AvsInformation](docs/AvsInformation.md)
 - [BalanceCacheModel](docs/BalanceCacheModel.md)
 - [BalanceInquiryRequestModel](docs/BalanceInquiryRequestModel.md)
 - [BankAccountFundingSourceModel](docs/BankAccountFundingSourceModel.md)
 - [BankAccountFundingSourceModelAllOf](docs/BankAccountFundingSourceModelAllOf.md)
 - [BankTransferClearingRequestModel](docs/BankTransferClearingRequestModel.md)
 - [BankTransferListResponse](docs/BankTransferListResponse.md)
 - [BankTransferRequestModel](docs/BankTransferRequestModel.md)
 - [BankTransferResponseModel](docs/BankTransferResponseModel.md)
 - [BankTransferTransitionListResponse](docs/BankTransferTransitionListResponse.md)
 - [BankTransferTransitionRequestModel](docs/BankTransferTransitionRequestModel.md)
 - [BankTransferTransitionResponseModel](docs/BankTransferTransitionResponseModel.md)
 - [BaseAchExtendedResponseModel](docs/BaseAchExtendedResponseModel.md)
 - [BaseAchRequestModel](docs/BaseAchRequestModel.md)
 - [BaseAchResponseModel](docs/BaseAchResponseModel.md)
 - [BeneficialOwnerRequest](docs/BeneficialOwnerRequest.md)
 - [BeneficialOwnerResponse](docs/BeneficialOwnerResponse.md)
 - [BillPaymentCompletionRequest](docs/BillPaymentCompletionRequest.md)
 - [BillPaymentTransactionRequest](docs/BillPaymentTransactionRequest.md)
 - [BillingAddress](docs/BillingAddress.md)
 - [BinPanIssuedCountResponse](docs/BinPanIssuedCountResponse.md)
 - [BulkCardOrderListResponse](docs/BulkCardOrderListResponse.md)
 - [BulkIssuanceRequest](docs/BulkIssuanceRequest.md)
 - [BulkIssuanceResponse](docs/BulkIssuanceResponse.md)
 - [BulkRequestModel](docs/BulkRequestModel.md)
 - [BusinessCardHolderListResponse](docs/BusinessCardHolderListResponse.md)
 - [BusinessCardHolderResponse](docs/BusinessCardHolderResponse.md)
 - [BusinessCardHolderUpdate](docs/BusinessCardHolderUpdate.md)
 - [BusinessCardholder](docs/BusinessCardholder.md)
 - [BusinessIncorporation](docs/BusinessIncorporation.md)
 - [BusinessIncorporationResponse](docs/BusinessIncorporationResponse.md)
 - [BusinessMetadata](docs/BusinessMetadata.md)
 - [BusinessProprietor](docs/BusinessProprietor.md)
 - [BusinessProprietorResponse](docs/BusinessProprietorResponse.md)
 - [BusinessTransitionListResponse](docs/BusinessTransitionListResponse.md)
 - [BusinessTransitionRequest](docs/BusinessTransitionRequest.md)
 - [BusinessTransitionResponse](docs/BusinessTransitionResponse.md)
 - [BusinessUserCardHolderListResponse](docs/BusinessUserCardHolderListResponse.md)
 - [CacheError](docs/CacheError.md)
 - [Cacheable](docs/Cacheable.md)
 - [CalculationSchedule](docs/CalculationSchedule.md)
 - [CalculationScheduleListResponse](docs/CalculationScheduleListResponse.md)
 - [CardAcceptorModel](docs/CardAcceptorModel.md)
 - [CardFulfillmentRequest](docs/CardFulfillmentRequest.md)
 - [CardFulfillmentResponse](docs/CardFulfillmentResponse.md)
 - [CardHolderAddressModel](docs/CardHolderAddressModel.md)
 - [CardHolderAddressUpdateModel](docs/CardHolderAddressUpdateModel.md)
 - [CardHolderModel](docs/CardHolderModel.md)
 - [CardHolderNoteListResponse](docs/CardHolderNoteListResponse.md)
 - [CardInventoryRequest](docs/CardInventoryRequest.md)
 - [CardInventoryResponse](docs/CardInventoryResponse.md)
 - [CardLifeCycle](docs/CardLifeCycle.md)
 - [CardListResponse](docs/CardListResponse.md)
 - [CardMetadata](docs/CardMetadata.md)
 - [CardOptions](docs/CardOptions.md)
 - [CardPersonalization](docs/CardPersonalization.md)
 - [CardProductConfig](docs/CardProductConfig.md)
 - [CardProductFulfillment](docs/CardProductFulfillment.md)
 - [CardProductFulfillmentResponse](docs/CardProductFulfillmentResponse.md)
 - [CardProductListResponse](docs/CardProductListResponse.md)
 - [CardProductRequest](docs/CardProductRequest.md)
 - [CardProductResponse](docs/CardProductResponse.md)
 - [CardProductUpdateModel](docs/CardProductUpdateModel.md)
 - [CardReorderRequest](docs/CardReorderRequest.md)
 - [CardRequest](docs/CardRequest.md)
 - [CardResponse](docs/CardResponse.md)
 - [CardSecurityCodeVerification](docs/CardSecurityCodeVerification.md)
 - [CardSwapHash](docs/CardSwapHash.md)
 - [CardTransitionListResponse](docs/CardTransitionListResponse.md)
 - [CardTransitionRequest](docs/CardTransitionRequest.md)
 - [CardTransitionResponse](docs/CardTransitionResponse.md)
 - [CardUpdateRequest](docs/CardUpdateRequest.md)
 - [CardValidationRequest](docs/CardValidationRequest.md)
 - [CardValidationResponse](docs/CardValidationResponse.md)
 - [CardholderAddressListResponse](docs/CardholderAddressListResponse.md)
 - [CardholderAddressResponse](docs/CardholderAddressResponse.md)
 - [CardholderAuthenticationData](docs/CardholderAuthenticationData.md)
 - [CardholderBalance](docs/CardholderBalance.md)
 - [CardholderBalances](docs/CardholderBalances.md)
 - [CardholderMetadata](docs/CardholderMetadata.md)
 - [CardholderMsaBalance](docs/CardholderMsaBalance.md)
 - [CardholderNoteRequestModel](docs/CardholderNoteRequestModel.md)
 - [CardholderNoteResponseModel](docs/CardholderNoteResponseModel.md)
 - [CardholderNoteUpdateRequestModel](docs/CardholderNoteUpdateRequestModel.md)
 - [Carrier](docs/Carrier.md)
 - [ChargebackAllocationAckRequest](docs/ChargebackAllocationAckRequest.md)
 - [ChargebackFundingSourceModel](docs/ChargebackFundingSourceModel.md)
 - [ChargebackFundingSourceModelAllOf](docs/ChargebackFundingSourceModelAllOf.md)
 - [ChargebackListResponse](docs/ChargebackListResponse.md)
 - [ChargebackRequest](docs/ChargebackRequest.md)
 - [ChargebackResponse](docs/ChargebackResponse.md)
 - [ChargebackTransitionListResponse](docs/ChargebackTransitionListResponse.md)
 - [ChargebackTransitionRequest](docs/ChargebackTransitionRequest.md)
 - [ChargebackTransitionResponse](docs/ChargebackTransitionResponse.md)
 - [ChargebackUpdateRequest](docs/ChargebackUpdateRequest.md)
 - [ClearingAndSettlement](docs/ClearingAndSettlement.md)
 - [ClearingFile](docs/ClearingFile.md)
 - [ClearingFileRequest](docs/ClearingFileRequest.md)
 - [ClearingFileResponse](docs/ClearingFileResponse.md)
 - [ClearingModel](docs/ClearingModel.md)
 - [ClearingRetryModel](docs/ClearingRetryModel.md)
 - [ClientAccessTokenRequest](docs/ClientAccessTokenRequest.md)
 - [ClientAccessTokenResponse](docs/ClientAccessTokenResponse.md)
 - [CommandoModeEnables](docs/CommandoModeEnables.md)
 - [CommandoModeListResponse](docs/CommandoModeListResponse.md)
 - [CommandoModeNestedTransition](docs/CommandoModeNestedTransition.md)
 - [CommandoModeRequest](docs/CommandoModeRequest.md)
 - [CommandoModeResponse](docs/CommandoModeResponse.md)
 - [CommandoModeTransitionListResponse](docs/CommandoModeTransitionListResponse.md)
 - [CommandoModeTransitionRequest](docs/CommandoModeTransitionRequest.md)
 - [CommandoModeTransitionResponse](docs/CommandoModeTransitionResponse.md)
 - [CommandoModeUpdateRequest](docs/CommandoModeUpdateRequest.md)
 - [ControlTokenRequest](docs/ControlTokenRequest.md)
 - [ControlTokenResponse](docs/ControlTokenResponse.md)
 - [CreateCacheRequestEntry](docs/CreateCacheRequestEntry.md)
 - [CreateCachesRequest](docs/CreateCachesRequest.md)
 - [CreateCachesResponse](docs/CreateCachesResponse.md)
 - [CronJobInfo](docs/CronJobInfo.md)
 - [CurrencyConversion](docs/CurrencyConversion.md)
 - [CustomerDueDiligenceRequest](docs/CustomerDueDiligenceRequest.md)
 - [CustomerDueDiligenceResponse](docs/CustomerDueDiligenceResponse.md)
 - [CustomerDueDiligenceUpdateRequest](docs/CustomerDueDiligenceUpdateRequest.md)
 - [DDARequest](docs/DDARequest.md)
 - [DepositAccountInfo](docs/DepositAccountInfo.md)
 - [DepositAccountInfoResponse](docs/DepositAccountInfoResponse.md)
 - [DepositAccountResponse](docs/DepositAccountResponse.md)
 - [DepositAccountUpdateRequest](docs/DepositAccountUpdateRequest.md)
 - [DepositDepositResponse](docs/DepositDepositResponse.md)
 - [Device](docs/Device.md)
 - [DigitalWalletAndroidPayProvisionRequest](docs/DigitalWalletAndroidPayProvisionRequest.md)
 - [DigitalWalletAndroidPayProvisionResponse](docs/DigitalWalletAndroidPayProvisionResponse.md)
 - [DigitalWalletApplePayProvisionRequest](docs/DigitalWalletApplePayProvisionRequest.md)
 - [DigitalWalletApplePayProvisionResponse](docs/DigitalWalletApplePayProvisionResponse.md)
 - [DigitalWalletSamsungPayProvisionRequest](docs/DigitalWalletSamsungPayProvisionRequest.md)
 - [DigitalWalletSamsungPayProvisionResponse](docs/DigitalWalletSamsungPayProvisionResponse.md)
 - [DigitalWalletToken](docs/DigitalWalletToken.md)
 - [DigitalWalletTokenAddressVerification](docs/DigitalWalletTokenAddressVerification.md)
 - [DigitalWalletTokenDevice](docs/DigitalWalletTokenDevice.md)
 - [DigitalWalletTokenHash](docs/DigitalWalletTokenHash.md)
 - [DigitalWalletTokenListResponse](docs/DigitalWalletTokenListResponse.md)
 - [DigitalWalletTokenMetadata](docs/DigitalWalletTokenMetadata.md)
 - [DigitalWalletTokenRequestorMapModel](docs/DigitalWalletTokenRequestorMapModel.md)
 - [DigitalWalletTokenRequestorMapUpdateModel](docs/DigitalWalletTokenRequestorMapUpdateModel.md)
 - [DigitalWalletTokenTransitionListResponse](docs/DigitalWalletTokenTransitionListResponse.md)
 - [DigitalWalletTokenTransitionRequest](docs/DigitalWalletTokenTransitionRequest.md)
 - [DigitalWalletTokenTransitionResponse](docs/DigitalWalletTokenTransitionResponse.md)
 - [DigitalWalletTokenWalletProvider](docs/DigitalWalletTokenWalletProvider.md)
 - [DigitalWalletTokenization](docs/DigitalWalletTokenization.md)
 - [DigitalWalletXPayProvisionRequest](docs/DigitalWalletXPayProvisionRequest.md)
 - [DigitalWalletXPayProvisionResponse](docs/DigitalWalletXPayProvisionResponse.md)
 - [DirectDepositAccountListResponse](docs/DirectDepositAccountListResponse.md)
 - [DirectDepositAccountRequest](docs/DirectDepositAccountRequest.md)
 - [DirectDepositAccountResponse](docs/DirectDepositAccountResponse.md)
 - [DirectDepositAccountTransitionRequest](docs/DirectDepositAccountTransitionRequest.md)
 - [DirectDepositAccountTransitionResponse](docs/DirectDepositAccountTransitionResponse.md)
 - [DirectDepositFundingSourceModel](docs/DirectDepositFundingSourceModel.md)
 - [DirectDepositFundingSourceModelAllOf](docs/DirectDepositFundingSourceModelAllOf.md)
 - [DirectDepositListResponse](docs/DirectDepositListResponse.md)
 - [DirectDepositRequest](docs/DirectDepositRequest.md)
 - [DirectDepositTransitionListResponse](docs/DirectDepositTransitionListResponse.md)
 - [DirectDepositTransitionRequest](docs/DirectDepositTransitionRequest.md)
 - [DirectDepositTransitionResponse](docs/DirectDepositTransitionResponse.md)
 - [DisputeModel](docs/DisputeModel.md)
 - [DisputeTransactionRequest](docs/DisputeTransactionRequest.md)
 - [EarlyFundsRequestModel](docs/EarlyFundsRequestModel.md)
 - [EchoPingRequest](docs/EchoPingRequest.md)
 - [EchoPingResponse](docs/EchoPingResponse.md)
 - [ErrorMessageFromWebPushProvisioningRequest](docs/ErrorMessageFromWebPushProvisioningRequest.md)
 - [ExpirationOffset](docs/ExpirationOffset.md)
 - [Fee](docs/Fee.md)
 - [FeeDetail](docs/FeeDetail.md)
 - [FeeListResponse](docs/FeeListResponse.md)
 - [FeeModel](docs/FeeModel.md)
 - [FeeRequest](docs/FeeRequest.md)
 - [FeeTransferRequest](docs/FeeTransferRequest.md)
 - [FeeTransferResponse](docs/FeeTransferResponse.md)
 - [FeeUpdateRequest](docs/FeeUpdateRequest.md)
 - [FileProcessingRequest](docs/FileProcessingRequest.md)
 - [FileProcessingResponse](docs/FileProcessingResponse.md)
 - [FinancialRequestModel](docs/FinancialRequestModel.md)
 - [FraudStreamRequest](docs/FraudStreamRequest.md)
 - [FraudView](docs/FraudView.md)
 - [FulfillmentAddressRequest](docs/FulfillmentAddressRequest.md)
 - [FulfillmentAddressResponse](docs/FulfillmentAddressResponse.md)
 - [FulfillmentRequest](docs/FulfillmentRequest.md)
 - [FulfillmentResponse](docs/FulfillmentResponse.md)
 - [Funding](docs/Funding.md)
 - [FundingAccountListResponse](docs/FundingAccountListResponse.md)
 - [FundingAccountResponseModel](docs/FundingAccountResponseModel.md)
 - [FundingRequestModel](docs/FundingRequestModel.md)
 - [FundingResponseModel](docs/FundingResponseModel.md)
 - [FundingSourceModel](docs/FundingSourceModel.md)
 - [FundingTranlog](docs/FundingTranlog.md)
 - [GLEntry](docs/GLEntry.md)
 - [GPA](docs/GPA.md)
 - [GPAUnloadListResponse](docs/GPAUnloadListResponse.md)
 - [GatewayClearingRequest](docs/GatewayClearingRequest.md)
 - [GatewayLogModel](docs/GatewayLogModel.md)
 - [GatewayProgramCustomHeaderUpdateRequest](docs/GatewayProgramCustomHeaderUpdateRequest.md)
 - [GatewayProgramFundingSourceRequest](docs/GatewayProgramFundingSourceRequest.md)
 - [GatewayProgramFundingSourceResponse](docs/GatewayProgramFundingSourceResponse.md)
 - [GatewayProgramFundingSourceUpdateRequest](docs/GatewayProgramFundingSourceUpdateRequest.md)
 - [GatewayProgramVersionUpdateRequest](docs/GatewayProgramVersionUpdateRequest.md)
 - [GatewayResponse](docs/GatewayResponse.md)
 - [Gatewaylog](docs/Gatewaylog.md)
 - [GlTransactionRequest](docs/GlTransactionRequest.md)
 - [GpaRequest](docs/GpaRequest.md)
 - [GpaResponse](docs/GpaResponse.md)
 - [GpaReturns](docs/GpaReturns.md)
 - [HealthCheckResult](docs/HealthCheckResult.md)
 - [HoldIncrease](docs/HoldIncrease.md)
 - [IdentificationRequestModel](docs/IdentificationRequestModel.md)
 - [IdentificationResponseModel](docs/IdentificationResponseModel.md)
 - [Images](docs/Images.md)
 - [ImagesCard](docs/ImagesCard.md)
 - [ImagesCarrier](docs/ImagesCarrier.md)
 - [ImagesCarrierReturnWindow](docs/ImagesCarrierReturnWindow.md)
 - [ImagesSignature](docs/ImagesSignature.md)
 - [InAppProvisioning](docs/InAppProvisioning.md)
 - [InstallmentPayment](docs/InstallmentPayment.md)
 - [InternalAccount](docs/InternalAccount.md)
 - [InternalAddressVerificationRequest](docs/InternalAddressVerificationRequest.md)
 - [InternalAuthControlRequest](docs/InternalAuthControlRequest.md)
 - [InternalAuthorizationTransaction](docs/InternalAuthorizationTransaction.md)
 - [InternalCard](docs/InternalCard.md)
 - [InternalCardProduct](docs/InternalCardProduct.md)
 - [InternalConfigsRequest](docs/InternalConfigsRequest.md)
 - [InternalConfigsResponse](docs/InternalConfigsResponse.md)
 - [InternalCryptoKey](docs/InternalCryptoKey.md)
 - [InternalCryptoKeyRequest](docs/InternalCryptoKeyRequest.md)
 - [InternalCryptoKeyRequestModel](docs/InternalCryptoKeyRequestModel.md)
 - [InternalCryptoKeyResponse](docs/InternalCryptoKeyResponse.md)
 - [InternalDepositAccountInformation](docs/InternalDepositAccountInformation.md)
 - [InternalDigitalWallet](docs/InternalDigitalWallet.md)
 - [InternalDigitalWalletToken](docs/InternalDigitalWalletToken.md)
 - [InternalFindOriginalRequest](docs/InternalFindOriginalRequest.md)
 - [InternalFindOriginalResponse](docs/InternalFindOriginalResponse.md)
 - [InternalFundingSource](docs/InternalFundingSource.md)
 - [InternalGPAOrder](docs/InternalGPAOrder.md)
 - [InternalGatewayLog](docs/InternalGatewayLog.md)
 - [InternalGatewayMerchant](docs/InternalGatewayMerchant.md)
 - [InternalGatewayResponse](docs/InternalGatewayResponse.md)
 - [InternalNetworkTransactionRequest](docs/InternalNetworkTransactionRequest.md)
 - [InternalSysConfig](docs/InternalSysConfig.md)
 - [InternalTransactionDataModel](docs/InternalTransactionDataModel.md)
 - [InternalTransactionMessage](docs/InternalTransactionMessage.md)
 - [InternalTransactionResponse](docs/InternalTransactionResponse.md)
 - [InternalUser](docs/InternalUser.md)
 - [InternalUserTransactionRequest](docs/InternalUserTransactionRequest.md)
 - [Iso8583DigitalWalletToken](docs/Iso8583DigitalWalletToken.md)
 - [Issuer](docs/Issuer.md)
 - [IssuerFraudView](docs/IssuerFraudView.md)
 - [JitAddressVerification](docs/JitAddressVerification.md)
 - [JitFunding](docs/JitFunding.md)
 - [JitFundingApi](docs/JitFundingApi.md)
 - [JitFundingPaymentcardFundingSource](docs/JitFundingPaymentcardFundingSource.md)
 - [JitFundingProgramFundingSource](docs/JitFundingProgramFundingSource.md)
 - [JitFundingProgramgatewayFundingSource](docs/JitFundingProgramgatewayFundingSource.md)
 - [JitProgramResponse](docs/JitProgramResponse.md)
 - [KYCListResponse](docs/KYCListResponse.md)
 - [KYCSubmitAnswersRequestModel](docs/KYCSubmitAnswersRequestModel.md)
 - [KycAnswer](docs/KycAnswer.md)
 - [KycRequest](docs/KycRequest.md)
 - [KycResponse](docs/KycResponse.md)
 - [Link](docs/Link.md)
 - [LinkedAccountBalanceResponse](docs/LinkedAccountBalanceResponse.md)
 - [LoadRuleListResponse](docs/LoadRuleListResponse.md)
 - [LoadVelocityModel](docs/LoadVelocityModel.md)
 - [LoginRequestModel](docs/LoginRequestModel.md)
 - [LoginResponseModel](docs/LoginResponseModel.md)
 - [MCCConfig](docs/MCCConfig.md)
 - [MCCGroupListResponse](docs/MCCGroupListResponse.md)
 - [MSA](docs/MSA.md)
 - [ManualEntry](docs/ManualEntry.md)
 - [MccGroupModel](docs/MccGroupModel.md)
 - [MccGroupUpdateModel](docs/MccGroupUpdateModel.md)
 - [MerchantCardRequest](docs/MerchantCardRequest.md)
 - [MerchantGroupListResponse](docs/MerchantGroupListResponse.md)
 - [MerchantGroupRequest](docs/MerchantGroupRequest.md)
 - [MerchantGroupResponse](docs/MerchantGroupResponse.md)
 - [MerchantGroupUpdateRequest](docs/MerchantGroupUpdateRequest.md)
 - [MerchantResponseModel](docs/MerchantResponseModel.md)
 - [MerchantScope](docs/MerchantScope.md)
 - [MinOffset](docs/MinOffset.md)
 - [MoneyInTransaction](docs/MoneyInTransaction.md)
 - [MoneyModel](docs/MoneyModel.md)
 - [MonitorResponse](docs/MonitorResponse.md)
 - [MsaAggregatedBalances](docs/MsaAggregatedBalances.md)
 - [MsaBalances](docs/MsaBalances.md)
 - [MsaOrderResponse](docs/MsaOrderResponse.md)
 - [MsaReturns](docs/MsaReturns.md)
 - [Network](docs/Network.md)
 - [NetworkAccountIntelligenceScore](docs/NetworkAccountIntelligenceScore.md)
 - [NetworkFeeModel](docs/NetworkFeeModel.md)
 - [NetworkFraudView](docs/NetworkFraudView.md)
 - [NetworkMetadata](docs/NetworkMetadata.md)
 - [OfferModel](docs/OfferModel.md)
 - [OfferOrderAggregatedBalances](docs/OfferOrderAggregatedBalances.md)
 - [OfferOrderBalances](docs/OfferOrderBalances.md)
 - [OfferOrderResponse](docs/OfferOrderResponse.md)
 - [OneTimeRequestModel](docs/OneTimeRequestModel.md)
 - [OrderScope](docs/OrderScope.md)
 - [OriginalCredit](docs/OriginalCredit.md)
 - [OriginalCreditSenderData](docs/OriginalCreditSenderData.md)
 - [OriginalDataElements](docs/OriginalDataElements.md)
 - [OrignalcreditRequestModel](docs/OrignalcreditRequestModel.md)
 - [OtherPoi](docs/OtherPoi.md)
 - [PTCAddress](docs/PTCAddress.md)
 - [PTCPhone](docs/PTCPhone.md)
 - [PTCSoftDescriptor](docs/PTCSoftDescriptor.md)
 - [Pagination](docs/Pagination.md)
 - [PanRequest](docs/PanRequest.md)
 - [PanResponse](docs/PanResponse.md)
 - [PasswordUpdateModel](docs/PasswordUpdateModel.md)
 - [PaymentCardFundingSourceModel](docs/PaymentCardFundingSourceModel.md)
 - [PaymentCardFundingSourceModelAllOf](docs/PaymentCardFundingSourceModelAllOf.md)
 - [PaymentCardResponseModel](docs/PaymentCardResponseModel.md)
 - [PeerTransferRequest](docs/PeerTransferRequest.md)
 - [PeerTransferResponse](docs/PeerTransferResponse.md)
 - [PinRequest](docs/PinRequest.md)
 - [PinRevealRequest](docs/PinRevealRequest.md)
 - [PingResponse](docs/PingResponse.md)
 - [PingResponseExtended](docs/PingResponseExtended.md)
 - [Poi](docs/Poi.md)
 - [Pos](docs/Pos.md)
 - [PreKycControls](docs/PreKycControls.md)
 - [PrecedingTransaction](docs/PrecedingTransaction.md)
 - [PrimaryContactInfoModel](docs/PrimaryContactInfoModel.md)
 - [Program](docs/Program.md)
 - [ProgramFundingSourceAchUpdateRequest](docs/ProgramFundingSourceAchUpdateRequest.md)
 - [ProgramFundingSourceListResponse](docs/ProgramFundingSourceListResponse.md)
 - [ProgramFundingSourceModel](docs/ProgramFundingSourceModel.md)
 - [ProgramFundingSourceRequest](docs/ProgramFundingSourceRequest.md)
 - [ProgramFundingSourceResponse](docs/ProgramFundingSourceResponse.md)
 - [ProgramFundingSourceUpdateRequest](docs/ProgramFundingSourceUpdateRequest.md)
 - [ProgramGatewayFundingSourceModel](docs/ProgramGatewayFundingSourceModel.md)
 - [ProgramReserveAccountBalance](docs/ProgramReserveAccountBalance.md)
 - [ProgramReserveDepositRequest](docs/ProgramReserveDepositRequest.md)
 - [ProgramReserveTransactionClearingRequest](docs/ProgramReserveTransactionClearingRequest.md)
 - [ProgramReserveTransactionListResponse](docs/ProgramReserveTransactionListResponse.md)
 - [ProgramReserveTransactionRequest](docs/ProgramReserveTransactionRequest.md)
 - [ProgramReserveTransactionResponse](docs/ProgramReserveTransactionResponse.md)
 - [ProgramTransfer](docs/ProgramTransfer.md)
 - [ProgramTransferListResponse](docs/ProgramTransferListResponse.md)
 - [ProgramTransferResponse](docs/ProgramTransferResponse.md)
 - [ProgramTransferTypeListResponse](docs/ProgramTransferTypeListResponse.md)
 - [ProgramTransferTypeRequest](docs/ProgramTransferTypeRequest.md)
 - [ProgramTransferTypeResponse](docs/ProgramTransferTypeResponse.md)
 - [ProvisioningControls](docs/ProvisioningControls.md)
 - [PublishEFTToTrancacheAndWebhookQueue](docs/PublishEFTToTrancacheAndWebhookQueue.md)
 - [PublishTransferResponse](docs/PublishTransferResponse.md)
 - [PullFromCardTransferResponse](docs/PullFromCardTransferResponse.md)
 - [PushToCardDisburseListResponse](docs/PushToCardDisburseListResponse.md)
 - [PushToCardDisburseRequest](docs/PushToCardDisburseRequest.md)
 - [PushToCardDisbursementResponse](docs/PushToCardDisbursementResponse.md)
 - [PushToCardListResponse](docs/PushToCardListResponse.md)
 - [PushToCardRequest](docs/PushToCardRequest.md)
 - [PushToCardResponse](docs/PushToCardResponse.md)
 - [RealTimeFeeAssessment](docs/RealTimeFeeAssessment.md)
 - [RealTimeFeeAssessmentRequest](docs/RealTimeFeeAssessmentRequest.md)
 - [RealTimeFeeGroup](docs/RealTimeFeeGroup.md)
 - [RealTimeFeeGroupCreateRequest](docs/RealTimeFeeGroupCreateRequest.md)
 - [RealTimeFeeGroupListResponse](docs/RealTimeFeeGroupListResponse.md)
 - [RealTimeFeeGroupRequest](docs/RealTimeFeeGroupRequest.md)
 - [RealTimeStandinCriteria](docs/RealTimeStandinCriteria.md)
 - [ReplacementAmount](docs/ReplacementAmount.md)
 - [ReportRequest](docs/ReportRequest.md)
 - [RequestForApplePayWppJWT](docs/RequestForApplePayWppJWT.md)
 - [RequestForWppParameters](docs/RequestForWppParameters.md)
 - [ResetUserPasswordEmailModel](docs/ResetUserPasswordEmailModel.md)
 - [ResetUserPasswordModel](docs/ResetUserPasswordModel.md)
 - [Response](docs/Response.md)
 - [Result](docs/Result.md)
 - [ResultCode](docs/ResultCode.md)
 - [ResultCodeInfo](docs/ResultCodeInfo.md)
 - [ReversalModel](docs/ReversalModel.md)
 - [RiskAssessment](docs/RiskAssessment.md)
 - [RiskcontrolTags](docs/RiskcontrolTags.md)
 - [SamsungPushTokenizeRequestData](docs/SamsungPushTokenizeRequestData.md)
 - [SelectiveAuth](docs/SelectiveAuth.md)
 - [SendingProvisioningDataToGooglePayBackendRequest](docs/SendingProvisioningDataToGooglePayBackendRequest.md)
 - [SettlementData](docs/SettlementData.md)
 - [Shipping](docs/Shipping.md)
 - [ShippingInformationResponse](docs/ShippingInformationResponse.md)
 - [SimulateIncrementalAuthRequest](docs/SimulateIncrementalAuthRequest.md)
 - [SimulatePinDebitAuthRequest](docs/SimulatePinDebitAuthRequest.md)
 - [SimulationResponseModel](docs/SimulationResponseModel.md)
 - [Special](docs/Special.md)
 - [SpendControlAssociation](docs/SpendControlAssociation.md)
 - [SsnResponseModel](docs/SsnResponseModel.md)
 - [StoreResponseModel](docs/StoreResponseModel.md)
 - [StrongCustomerAuthenticationLimits](docs/StrongCustomerAuthenticationLimits.md)
 - [TabaPayAccounts](docs/TabaPayAccounts.md)
 - [TabaPayAddPaymentInstrumentRequest](docs/TabaPayAddPaymentInstrumentRequest.md)
 - [TabaPayCard](docs/TabaPayCard.md)
 - [TabaPayName](docs/TabaPayName.md)
 - [TabaPayOwner](docs/TabaPayOwner.md)
 - [TabaPayPayoutRequest](docs/TabaPayPayoutRequest.md)
 - [TabaPayPush](docs/TabaPayPush.md)
 - [TabapayPTCAddress](docs/TabapayPTCAddress.md)
 - [TabapaySoftDescriptor](docs/TabapaySoftDescriptor.md)
 - [TabapaySoftDescriptorPhone](docs/TabapaySoftDescriptorPhone.md)
 - [Tag](docs/Tag.md)
 - [TerminalModel](docs/TerminalModel.md)
 - [Text](docs/Text.md)
 - [TextValue](docs/TextValue.md)
 - [TokenRequest](docs/TokenRequest.md)
 - [TokenServiceProvider](docs/TokenServiceProvider.md)
 - [TokenUpdateRequest](docs/TokenUpdateRequest.md)
 - [Track1Data](docs/Track1Data.md)
 - [TranLogAttributeRequest](docs/TranLogAttributeRequest.md)
 - [TranlogTokenWithInjectableDomainDataToPublishToTrancacheAndWebhookQueue](docs/TranlogTokenWithInjectableDomainDataToPublishToTrancacheAndWebhookQueue.md)
 - [Transaction](docs/Transaction.md)
 - [TransactionCachePayloadNullificationModel](docs/TransactionCachePayloadNullificationModel.md)
 - [TransactionCardAcceptor](docs/TransactionCardAcceptor.md)
 - [TransactionCardAcceptorViewModelV1](docs/TransactionCardAcceptorViewModelV1.md)
 - [TransactionControls](docs/TransactionControls.md)
 - [TransactionMetadata](docs/TransactionMetadata.md)
 - [TransactionModel](docs/TransactionModel.md)
 - [TransactionModelListResponse](docs/TransactionModelListResponse.md)
 - [TransactionOptions](docs/TransactionOptions.md)
 - [TransactionUpdateModel](docs/TransactionUpdateModel.md)
 - [Transit](docs/Transit.md)
 - [TriggeredRule](docs/TriggeredRule.md)
 - [UnloadRequestModel](docs/UnloadRequestModel.md)
 - [UpdateBusinessCheckRequestRequest](docs/UpdateBusinessCheckRequestRequest.md)
 - [UpdateSystemHealth](docs/UpdateSystemHealth.md)
 - [UserAssociation](docs/UserAssociation.md)
 - [UserCardHolderListResponse](docs/UserCardHolderListResponse.md)
 - [UserCardHolderResponse](docs/UserCardHolderResponse.md)
 - [UserCardHolderSearchModel](docs/UserCardHolderSearchModel.md)
 - [UserCardHolderUpdateModel](docs/UserCardHolderUpdateModel.md)
 - [UserStipBalanceRequest](docs/UserStipBalanceRequest.md)
 - [UserStipBalanceResponse](docs/UserStipBalanceResponse.md)
 - [UserTransitionListResponse](docs/UserTransitionListResponse.md)
 - [UserTransitionRequest](docs/UserTransitionRequest.md)
 - [UserTransitionResponse](docs/UserTransitionResponse.md)
 - [UserValidationRequest](docs/UserValidationRequest.md)
 - [UserValidationResponse](docs/UserValidationResponse.md)
 - [ValidationsRequest](docs/ValidationsRequest.md)
 - [ValidationsResponse](docs/ValidationsResponse.md)
 - [VelocityCache](docs/VelocityCache.md)
 - [VelocityControlBalanceListResponse](docs/VelocityControlBalanceListResponse.md)
 - [VelocityControlBalanceResponse](docs/VelocityControlBalanceResponse.md)
 - [VelocityControlCheckRequest](docs/VelocityControlCheckRequest.md)
 - [VelocityControlCheckResponse](docs/VelocityControlCheckResponse.md)
 - [VelocityControlListResponse](docs/VelocityControlListResponse.md)
 - [VelocityControlRequest](docs/VelocityControlRequest.md)
 - [VelocityControlResponse](docs/VelocityControlResponse.md)
 - [VelocityControlUpdateRequest](docs/VelocityControlUpdateRequest.md)
 - [WalletProviderCardOnFile](docs/WalletProviderCardOnFile.md)
 - [WalletProviderProfile](docs/WalletProviderProfile.md)
 - [WebPushProvisioning](docs/WebPushProvisioning.md)
 - [WebPushProvisioningApplePayJWSHeader](docs/WebPushProvisioningApplePayJWSHeader.md)
 - [WebPushProvisioningApplePayJWSModel](docs/WebPushProvisioningApplePayJWSModel.md)
 - [WebPushProvisioningApplePayJWTResponse](docs/WebPushProvisioningApplePayJWTResponse.md)
 - [Webhook](docs/Webhook.md)
 - [WebhookBaseModel](docs/WebhookBaseModel.md)
 - [WebhookConfigModel](docs/WebhookConfigModel.md)
 - [WebhookPingModel](docs/WebhookPingModel.md)
 - [WebhookRequestModel](docs/WebhookRequestModel.md)
 - [WebhookResponseModel](docs/WebhookResponseModel.md)
 - [WebhookResponseModelListResponse](docs/WebhookResponseModelListResponse.md)
 - [WebhookUpdateCustomHeaderRequest](docs/WebhookUpdateCustomHeaderRequest.md)
 - [WithdrawalRequestModel](docs/WithdrawalRequestModel.md)
 - [XpayPushTokenizeRequestData](docs/XpayPushTokenizeRequestData.md)


## Documentation For Authorization

 All endpoints do not require authorization.

## Author

dev@swadesh.co


